import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_events._jsii
import aws_cdk.aws_events_targets._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_logs._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@cloudcomponents/cdk-temp-stack",
    "1.0.10",
    __name__[0:-6],
    "cdk-temp-stack@1.0.10.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
